# alphascope
~ under dev

Developing and deploying an end-to-end python package for a subsection of computational finance.

## Installation
to install alphascope, along with the tools that would be required to develop and run tests, run the following
in your virtual environment:

'''bash
$ pip install -e .[dev]

## Usage
tbd

## Examples
tbd